/*
 * PIMPPA: Filetype related
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>
#include <unistd.h>
#include "proto.h"
#include "../src/pimppa.h"

static bowser_column typeDatas[7]=
    {{"type_ext", COLUMN_TEXT, 50, "", NULL},
     {"type_testcmd", COLUMN_TEXT, 150, "", NULL},
     {"type_testpos", COLUMN_NUMBER, 50, "0", NULL},
     {"type_testokstr", COLUMN_TEXT, 50, "OK", NULL},
     {"type_transcmd", COLUMN_TEXT, 150, "", NULL},
     {"type_transto", COLUMN_TEXT, 50, "", NULL},
     {"type_prunecmd", COLUMN_TEXT, 150, "", NULL}};
static bowser_table typeTable={typeDatas, "p_types", 7};

GtkWidget *get_types_box(void)
{
	return(get_table(&typeTable));
}

